pub struct AssetMetadata {
pub slot: Slot,
pub type_: AssetType,
pub size: u64,
pub sha256: Sha256,
pub url: AbsoluteComponentUrl,
}Expand description
Metadata describing a Zbi or Vbmeta image, whether or not it is for recovery, and where to resolve it from.
Fields
slot: Slottype_: AssetTypesize: u64sha256: Sha256url: AbsoluteComponentUrlImplementations
Sourceimpl AssetMetadata
impl AssetMetadata
Sourcepub fn new_from_metadata(
slot: Slot,
type_: AssetType,
metadata: ImageMetadata,
) -> Self
pub fn new_from_metadata( slot: Slot, type_: AssetType, metadata: ImageMetadata, ) -> Self
Creates a new AssetMetadata from the given image metadata and target slot/type.
Sourcepub fn metadata(&self) -> ImageMetadata
pub fn metadata(&self) -> ImageMetadata
Returns the ImageMetadata for this image.