pub struct ImageMetadata { /* private fields */ }Expand description
Metadata necessary to determine if a payload matches an image without needing to have the actual image.
Implementations
Sourceimpl ImageMetadata
impl ImageMetadata
Sourcepub fn new(size: u64, sha256: Sha256, url: AbsoluteComponentUrl) -> Self
pub fn new(size: u64, sha256: Sha256, url: AbsoluteComponentUrl) -> Self
Returns new image metadata that designates the given size and hash, which can be found
at the given url.
Sourcepub fn url(&self) -> &AbsoluteComponentUrl
pub fn url(&self) -> &AbsoluteComponentUrl
Returns the url of the image.
Sourcepub fn for_path(
path: &Utf8Path,
url: PinnedAbsolutePackageUrl,
resource: String,
) -> Result<Self, ImageMetadataError>
pub fn for_path( path: &Utf8Path, url: PinnedAbsolutePackageUrl, resource: String, ) -> Result<Self, ImageMetadataError>
Compute the size and hash for the image file located at path, determining the image’s
fuchsia-pkg URL using the given base url and resource path within the package.