pub struct ImagePackagesManifest {
pub assets: Vec<AssetMetadata>,
pub firmware: Vec<FirmwareMetadata>,
}Expand description
A manifest describing the various images and firmware packages that should be fetched and written during a system update, as well as metadata about those images and where to find them.
Fields
assets: Vec<AssetMetadata>firmware: Vec<FirmwareMetadata>Implementations
Sourceimpl ImagePackagesManifest
impl ImagePackagesManifest
Sourcepub fn builder() -> ImagePackagesManifestBuilder
pub fn builder() -> ImagePackagesManifestBuilder
Returns a ImagePackagesManifestBuilder with no configured images.
Sourcepub fn fuchsia(&self) -> Option<ZbiAndOptionalVbmetaMetadata>
pub fn fuchsia(&self) -> Option<ZbiAndOptionalVbmetaMetadata>
Returns metadata for the fuchsia boot slot, if present.
Sourcepub fn recovery(&self) -> Option<ZbiAndOptionalVbmetaMetadata>
pub fn recovery(&self) -> Option<ZbiAndOptionalVbmetaMetadata>
Returns metadata for the recovery boot slot, if present.
Sourcepub fn firmware(&self) -> BTreeMap<String, ImageMetadata>
pub fn firmware(&self) -> BTreeMap<String, ImageMetadata>
Returns metadata for the firmware images.