pub struct ImagePackagesManifestBuilder { /* private fields */ }Expand description
A builder of ImagePackagesManifest.
Implementations
Sourceimpl ImagePackagesManifestBuilder
impl ImagePackagesManifestBuilder
Sourcepub fn fuchsia_package(
&mut self,
zbi: ImageMetadata,
vbmeta: Option<ImageMetadata>,
) -> &mut Self
pub fn fuchsia_package( &mut self, zbi: ImageMetadata, vbmeta: Option<ImageMetadata>, ) -> &mut Self
Configures the “fuchsia” images package to use the given zbi metadata, and optional vbmeta metadata.
Sourcepub fn recovery_package(
&mut self,
zbi: ImageMetadata,
vbmeta: Option<ImageMetadata>,
) -> &mut Self
pub fn recovery_package( &mut self, zbi: ImageMetadata, vbmeta: Option<ImageMetadata>, ) -> &mut Self
Configures the “recovery” images package to use the given zbi metadata, and optional vbmeta metadata.
Sourcepub fn firmware_package(
&mut self,
firmware: BTreeMap<String, ImageMetadata>,
) -> &mut Self
pub fn firmware_package( &mut self, firmware: BTreeMap<String, ImageMetadata>, ) -> &mut Self
Configures the “firmware” images package from a BTreeMap of ImageMetadata
Sourcepub fn build(self) -> VersionedImagePackagesManifest
pub fn build(self) -> VersionedImagePackagesManifest
Returns the constructed manifest.