UpdatePackage

Struct UpdatePackage 

pub struct UpdatePackage { /* private fields */ }
An open handle to an “update” package.

Implementations

Source

impl UpdatePackage

pub fn new(proxy: DirectoryProxy) -> Self

Creates a new UpdatePackage with the given proxy.

pub async fn verify_name(&self) -> Result<(), VerifyNameError>

Verifies that the package’s name/variant is “update/0”.

pub async fn images_metadata( &self, ) -> Result<ImagesMetadata, ImagePackagesError>

Loads the image packages manifest, or determines that it is not present.

pub async fn verify_board(&self, contents: &str) -> Result<(), VerifyBoardError>

Verifies the board file has the given contents.

pub async fn update_mode( &self, ) -> Result<Option<UpdateMode>, ParseUpdateModeError>

Parses the update-mode file to obtain update mode. Returns Ok(None) if the update-mode file is not present in the update package.

pub async fn packages( &self, ) -> Result<Vec<PinnedAbsolutePackageUrl>, ParsePackageError>

Returns the list of package urls that go in the universe of this update package.

pub async fn hash(&self) -> Result<Hash, HashError>

Returns the package hash of this update package.

pub async fn version(&self) -> Result<SystemVersion, ReadVersionError>

Returns the version of this update package.

pub async fn epoch(&self) -> Result<Option<u64>, ParseEpochError>

Parses the epoch.json file to obtain the epoch. Returns Ok(None) if the epoch.json file is not present in the update package.