pub struct OtaManifest {
pub build_info_version: SystemVersion,
pub board: String,
pub epoch: u64,
pub mode: UpdateMode,
pub blob_base_url: String,
pub images: Vec<Image>,
pub blobs: Vec<Blob>,
}Expand description
Information about a particular version of the OS.
Fields
build_info_version: SystemVersionThe version from the build-info of the target build. This field is for
informational purposes only and does not change the updater’s behavior.
board: StringThe board this OTA is for (e.g., “x64”, “arm64”). The system updater will
reject the OTA if this does not match the device’s expected board name
from build-info.
epoch: u64The epoch of this OTA. See RFC-0071 for details.
mode: UpdateModeThe update mode, indicating if this is a normal update or a forced recovery.
blob_base_url: StringThe base URL prefix of the blobs, including the delivery blob type. The final URL for each blob will be “{blob_base_url}/{fuchsia_merkle_root}”. Relative URLs are supported, and will be resolved relative to the URL of the OTA manifest.
images: Vec<Image>The partition images that should be written during the update.
blobs: Vec<Blob>Additional blobs that should be written to blob storage.
Implementations